=================
Bottle Utils Lazy
=================

Bottle Utils is a collection of loosely related packages for developing web
applications using Bottle_ web framework. This package contains utilities for
lazy evaluation.

.. _Bottle: http://bottlepy.org/


